@@ -7,7 +7,7 @@ use warnings;
 use mro  ();
 use Carp ();
 
-use UNIVERSAL::Object;
+use UNIVERSAL::Object::Immutable;
 
 use MOP::Role;
 use MOP::Method;
@@ -15,10 +15,10 @@ use MOP::Slot;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.05';
+our $VERSION   = '0.06';
 our $AUTHORITY = 'cpan:STEVAN';
 
-our @ISA;  BEGIN { @ISA  = 'UNIVERSAL::Object' };
+our @ISA;  BEGIN { @ISA  = 'UNIVERSAL::Object::Immutable' };
 our @DOES; BEGIN { @DOES = 'MOP::Role' }; # to be composed later ...
 
 UNITCHECK {
@@ -64,7 +64,7 @@ MOP::Class - A representation of a class
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
