@@ -7,14 +7,14 @@ use warnings;
 use attributes ();
 use Carp       ();
 
-use UNIVERSAL::Object;
+use UNIVERSAL::Object::Immutable;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.05';
+our $VERSION   = '0.06';
 our $AUTHORITY = 'cpan:STEVAN';
 
-our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' };
+our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object::Immutable' };
 
 sub BUILDARGS {
     my $class = shift;
@@ -124,7 +124,7 @@ MOP::Method - A representation of a method
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
