@@ -6,17 +6,17 @@ use warnings;
 
 use Carp ();
 
-use UNIVERSAL::Object;
+use UNIVERSAL::Object::Immutable;
 
 use MOP::Method;
 use MOP::Slot;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.05';
+our $VERSION   = '0.06';
 our $AUTHORITY = 'cpan:STEVAN';
 
-our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' };
+our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object::Immutable' };
 
 sub BUILDARGS {
     my $class = shift;
@@ -806,7 +806,7 @@ MOP::Role - A representation of a role
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
